.. qcware documentation master file, created by
   sphinx-quickstart on Tue Aug 20 12:53:08 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Table of contents
-----------------

This documentation is a technical reference for the Quasar library. In order
to access Jupyter Notebook tutorials, which include explanations and examples 
of circuit-model programming using Quasar, first sign up for a Forge API key at
https://forge.qcware.com. Then click on the Jupyter Notebooks tab in Forge to 
go to your personal Notebook. Start with ``GettingStarted/Examples/Circuits/start_here.ipynb``
and refer to the following notebook documents corresponding to each topic:

* **Circuits and Gates:** 

   * ``GettingStarted/Examples/Circuits/quasar_circuit_composition.ipynb``
   * ``GettingStarted/Examples/Circuits/quasar_gate_library.ipynb``
   * ``GettingStarted/Examples/Circuits/quasar_parameters.ipynb``

* **Pauli Operators:**

   * ``GettingStarted/Examples/Circuits/quasar_derivatives.ipynb``
   * ``GettingStarted/Examples/Circuits/quasar_parameters.ipynb``
   * ``GettingStarted/Examples/Circuits/quasar_pauli.ipynb``

* **Backends:**

   * ``GettingStarted/Examples/Circuits/quasar_measurement.ipynb``

.. toctree::
   :maxdepth: 2
   :caption: Circuits

   circuits

.. toctree::
   :maxdepth: 2
   :caption: Pauli Operators

   pauli

.. toctree::
   :maxdepth: 2
   :caption: Backends

   backends

.. toctree::
   :maxdepth: 2
   :caption: Copyright

   copyright
